@@ -7,7 +7,7 @@ import (
 
 	"github.com/CycloneDX/cyclonedx-go"
 
-	v3 "github.com/anchore/grype/grype/db/v3"
+	grypeDb "github.com/anchore/grype/grype/db/v4"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/grype/internal/log"
@@ -101,7 +101,7 @@ func NewVulnerability(m match.Match, p vulnerability.MetadataProvider) (cycloned
 
 func makeProperties(fix vulnerability.Fix) *[]cyclonedx.Property {
 	properties := []cyclonedx.Property{}
-	if fix.State == v3.FixedState {
+	if fix.State == grypeDb.FixedState {
 		properties = append(properties, cyclonedx.Property{
 			Name:  "grype:fixed_versions",
 			Value: strings.Join(fix.Versions, ","),
